@@ -6,6 +6,6 @@ import os
 setup(name='touchsearch-quickbar',
    version='1.0',
    data_files = [
-      ('/opt/touchsearch/search_engines/QuickBar/',['QuickBar.search', 'quickbar.png'])
+      ('/opt/touchsearch/search_engines/QuickBar/',['QuickBar.search', 'quickbar_color.png', 'quickbar_ghosted.png'])
       ]
       )
\ No newline at end of file
