@@ -6,6 +6,6 @@ import os
 setup(name='touchsearch-youtube',
    version='1.0',
    data_files = [
-      ('/opt/touchsearch/search_engines/YouTube/',['YouTube.search', 'youtube.png'])
+      ('/opt/touchsearch/search_engines/YouTube/',['YouTube.search', 'youtube_color.png', 'youtube_ghosted.png'])
       ]
       )
\ No newline at end of file
